@@ -25,20 +25,21 @@ static CRITICAL_SECTION preadsc;
 /* http://stackoverflow.com/a/2390626/1392778 */
 
 #ifdef _MSC_VER
-
-#pragma section(".CRT$XCU",read)
-
-#define INITIALIZER(f)                                                  \
+    #pragma section(".CRT$XCU",read)
+    #define INITIALIZER2_(f, p)                                         \
     static void __cdecl f(void);                                        \
     __declspec(allocate(".CRT$XCU")) void(__cdecl * f ## _) (void) = f; \
+    __pragma(comment(linker, "/include:" p # f "_"))                    \
     static void __cdecl f(void)
-
+    #ifdef _WIN64
+        #define INITIALIZER(f) INITIALIZER2_(f, "")
+    #else
+        #define INITIALIZER(f) INITIALIZER2_(f, "_")
+    #endif
 #elif defined(__GNUC__)
-
-#define INITIALIZER(f)                                \
+    #define INITIALIZER(f)                            \
     static void f(void) __attribute__((constructor)); \
     static void f(void)
-
 #endif
 
 
